% -------------------------------------------------------------------------
% run_g7play.m (edited 1/13/16)

% Matlab program to run the MU box which can simultaneously 
% output voltages on 2 channels, and measure voltage input on 2 channels 
% -------------------------------------------------------------------------
addpath bin;

% Choose one of the following (g7string plays the executable from the
% correct directory). 
%addpath MAC; g7string = './MAC/g7play'; % MAC option
addpath WINDOWS; g7string = '.\WINDOWS\g7play'; % WINDOWS option
%addpath LINUX; g7string = './LINUX/g7play'; % LINUX option

% NOTE: Test the Matlab command "system(g7string)" (if g7play isn't 
% recognized, this string is probably wrong).
% TO TEST G7PLAY: Make sure your current directory is the 'all' folder
% (level where this program is located, containing WINDOWS, MAC, LINUX
% folders). Then, in the command window, type one of the following (based
% on your OS):
% system('./MAC/g7play')
% system('.\WINDOWS\g7play')
% system('./LINUX/g7play')
% If this works, try a variation, i.e. system('.\WINDOWS\g7play -H')
% If you are inside the SAME DIRECTORY as the g7play executable, the
% syntax will be system('./g7play') (LINUX, MAC) or system('.\g7play') (WINDOWS)

% -------------------------------------------------------------------------
% Initialize parameters & settings
% -------------------------------------------------------------------------
Nmax=2^31-1; % max integer 
Navg=100; % number of blocks sent/received to be averaged together
NFT=1024; % discrete fourier transform length 
NF=NFT/2+1; % number of frequency bins
Fs=48000; % sampling frequency
Ts=1/Fs; % sampling period
Fmax=Fs/2; % max frequency
Fmin=Fs/NFT; % minimum (non-zero) frequency & frequency bin size
f=Fmin*(0:NF-1); % vector of frequencies (in Hertz)
t=Ts*(0:NFT-1); % vector of times (in seconds)
G=0.01; % gain paramter
% NOTE: The time-domain signal is normalized so that the maximum value is 1. 
% The gain value G scales this signal. Example: If G =0.01, then the
% maximum value of the time-domain signal will be 0.01*VmaxDA (e.g. the
% output voltage is a specified fraction of the D/A voltage range).

global V; % global parameters to be read by rd1.m
V=struct( 'Fs',Fs, 'NFT',NFT, 'f',f, 't',t); 
V.VmaxDA = 2.216; V.VmaxAD = 1.37; % DAC parameters for calculating actual voltages

% -------------------------------------------------------------------------
% Generate output signals (left and right channel)
% -------------------------------------------------------------------------
% Creat a chirp signal (typically the type of signal we wish to use)
phi=(0:NF-1)/(NF-1); % initialize vector for chirp phase
phi=(NFT/2)*pi*phi.*phi; % set frequency-domain phase of chirp (quadratic) 
S=exp(-1j*phi); % frequency-domain signal
s=fsst(S); % calculate time-domain signal (fsst.m takes the inverse fourier transform of C(f))
s=0.999*s/max(abs(s)); % normalize time-domain signal so its highest value is almost 1
S=fast(s); % re-calculate frequency-domain signal (fast.m takes the fourier transform of c(t))

S0=S; % set frequency-domain signal for "left" output channel
S1=S; % set frequency-domain signal for "right" output channel
s0=fsst(S0); s1=fsst(S1); % calculate corresponding "time-domain" signals

% apply gain parameter
G0=G; G1=G; % set channel gain equal to G for both channels
s0=round(G0*s0*Nmax); %Scale data to int32 2^31-1 range & apply gain
s1=round(G0*s1*Nmax);

%s0 = zeros(size(s0,1),size(s0,2)); %turn off CH0-OUT 
%s1 = zeros(size(s1,1),size(s1,2)); %turn off CH1-OUT

%save the data in files stim0 and stim1
fd=fopen('data/stim0','w');
N=fwrite(fd,s0,'int32'); %Scale to Nmax (32 bit integer)
fclose(fd);

fd=fopen('data/stim1','w');
N=fwrite(fd,s1,'int32'); %Scale to Nmax (32 bit integer)
fclose(fd);

delete('data/resp*'); % clear old data (* means any file beginning with resp)

%--------------------------------------------------------------------------
%Play chirps via the hand-held  (the main act!)
%--------------------------------------------------------------------------
disp('chirp via handheld'); % will show in Matlab's command window
%analog=sprintf('%s -H',g7string); % show g7play options

% create g7play command string (for more options, use -H)
analog=sprintf('%s -Q 0 -B %d -R0 data/stim0 -R1 data/stim1 -C0 data/resp0 -C1 data/resp1 -S %d ',g7string,Navg,NFT);

disp(analog); % dispay string in Matlab command window
system(analog); % run g7 play in the command line of your operating system

% -------------------------------------------------------------------------
% Analyze and plot data
% -------------------------------------------------------------------------
save('data\V.mat','V')

if exist('data/resp0','file')>0 % if no data was saved, don't call rd1.m
    show_data % call function to plot stuff
end


